@@ -224,7 +224,7 @@ class Client:
     async def get_mq_conn(self):
         return await self.mq.get_mq_conn()
 
-    async def put_from_cloud_async(self, url, bucket, bucket_name, timeout, file_ttl, mq=None):
+    async def put_from_cloud_async(self, url, bucket, bucket_name, timeout=10, file_ttl=-1, mq=None):
         # save to cache
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
         ret = await self.mq.async_publish(self.put_topic, {
